@@ -70,6 +70,12 @@ class ListNamespace(_StoresCompliant[CompliantT_co], Protocol[CompliantT_co]):
     def len(self) -> CompliantT_co: ...
     def unique(self) -> CompliantT_co: ...
     def contains(self, item: NonNestedLiteral) -> CompliantT_co: ...
+    def min(self) -> CompliantT_co: ...
+    def max(self) -> CompliantT_co: ...
+    def mean(self) -> CompliantT_co: ...
+    def median(self) -> CompliantT_co: ...
+    def sum(self) -> CompliantT_co: ...
+    def sort(self, *, descending: bool, nulls_last: bool) -> CompliantT_co: ...
 
 
 class NameNamespace(_StoresCompliant[CompliantT_co], Protocol[CompliantT_co]):
@@ -101,6 +107,8 @@ class StringNamespace(_StoresCompliant[T], Protocol[T]):
     def to_titlecase(self) -> T: ...
     def to_uppercase(self) -> T: ...
     def zfill(self, width: int) -> T: ...
+    def pad_start(self, length: int, fill_char: str) -> T: ...
+    def pad_end(self, length: int, fill_char: str) -> T: ...
 
 
 class StructNamespace(_StoresCompliant[CompliantT_co], Protocol[CompliantT_co]):
