@@ -62,6 +62,12 @@ def pytest_addoption(parser: pytest.Parser) -> None:
         default=False,
         help="run tests with all cpu constructors",
     )
+    parser.addoption(
+        "--use-external-constructor",
+        action="store_true",
+        default=False,
+        help="run tests with external constructor",
+    )
     parser.addoption(
         "--constructors",
         action="store",
@@ -142,16 +148,16 @@ def polars_lazy_constructor(obj: Data) -> pl.LazyFrame:
     return pl.LazyFrame(obj)
 
 
-def duckdb_lazy_constructor(obj: Data) -> NativeDuckDB:
+def duckdb_lazy_constructor(obj: dict[str, Any]) -> NativeDuckDB:
     pytest.importorskip("duckdb")
     pytest.importorskip("pyarrow")
     import duckdb
-    import polars as pl
+    import pyarrow as pa
 
     duckdb.sql("""set timezone = 'UTC'""")
 
-    _df = pl.LazyFrame(obj)
-    return duckdb.table("_df")
+    _df = pa.table(obj)
+    return duckdb.sql("select * from _df")
 
 
 def dask_lazy_p1_constructor(obj: Data) -> NativeDask:  # pragma: no cover
@@ -250,6 +256,8 @@ GPU_CONSTRUCTORS: dict[str, ConstructorEager] = {"cudf": cudf_constructor}
 
 
 def pytest_generate_tests(metafunc: pytest.Metafunc) -> None:
+    if metafunc.config.getoption("use_external_constructor"):  # pragma: no cover
+        return  # let the plugin handle this
     if metafunc.config.getoption("all_cpu_constructors"):  # pragma: no cover
         selected_constructors: list[str] = [
             *iter(EAGER_CONSTRUCTORS.keys()),
