@@ -45,12 +45,13 @@ def test_series_floordiv_by_zero(
     request: pytest.FixtureRequest,
     get_denominator: Callable[[nw.DataFrame[Any]], int | nw.Series[Any]],
 ) -> None:
+    df = nw.from_native(constructor_eager(data), eager_only=True)
+
     if "polars" in str(constructor_eager) and POLARS_VERSION < (0, 20, 7):
         pytest.skip(reason="bug")
-    if any(x in str(constructor_eager) for x in ("pandas", "modin", "cudf")):
+    if df.implementation.is_pandas_like():
         request.applymarker(pytest.mark.xfail)
 
-    df = nw.from_native(constructor_eager(data), eager_only=True)
     denominator = get_denominator(df)
     result = {"result": df["int"] // denominator}
     expected = {"result": expected_floordiv}
@@ -61,13 +62,13 @@ def test_series_floordiv_by_zero(
 def test_expr_floordiv_by_zero(
     constructor: Constructor, request: pytest.FixtureRequest, denominator: int | nw.Expr
 ) -> None:
+    df = nw.from_native(constructor(data))
+
     if "polars" in str(constructor) and POLARS_VERSION < (0, 20, 7):
         pytest.skip(reason="bug")
-    if any(x in str(constructor) for x in ("pandas", "modin", "cudf")):
+    if df.implementation.is_pandas_like():
         request.applymarker(pytest.mark.xfail)
 
-    df = nw.from_native(constructor(data))
-
     result = df.select(result=nw.col("int") // denominator)
     expected = {"result": expected_floordiv}
     assert_equal_data(result, expected)
@@ -109,7 +110,9 @@ def test_series_rfloordiv_by_zero(
 ) -> None:
     if "polars" in str(constructor_eager) and POLARS_VERSION < (0, 20, 7):
         pytest.skip(reason="bug")
-    if any(x in str(constructor_eager) for x in ("pandas_pyarrow", "modin_pyarrow")) or (
+    if any(
+        x in str(constructor_eager) for x in ("pandas_pyarrow", "modin_pyarrow", "cudf")
+    ) or (
         any(
             x in str(constructor_eager)
             for x in ("pandas_nullable", "pandas_constructor", "modin_constructor")
@@ -119,6 +122,7 @@ def test_series_rfloordiv_by_zero(
         request.applymarker(pytest.mark.xfail)
 
     df = nw.from_native(constructor_eager(data), eager_only=True)
+
     result = {"result": numerator // df["denominator"]}
     assert_equal_data(result, {"result": expected_floordiv})
 
@@ -129,8 +133,9 @@ def test_expr_rfloordiv_by_zero(
 ) -> None:
     if "polars" in str(constructor) and POLARS_VERSION < (0, 20, 7):
         pytest.skip(reason="bug")
-
-    if any(x in str(constructor) for x in ("pandas_pyarrow", "modin_pyarrow")) or (
+    if any(
+        x in str(constructor) for x in ("pandas_pyarrow", "modin_pyarrow", "cudf")
+    ) or (
         any(
             x in str(constructor)
             for x in ("pandas_nullable", "pandas_constructor", "modin_constructor")
@@ -140,6 +145,7 @@ def test_expr_rfloordiv_by_zero(
         request.applymarker(pytest.mark.xfail)
 
     df = nw.from_native(constructor(data))
+
     result = df.select(result=numerator // nw.col("denominator"))
     expected = {"result": expected_floordiv}
     assert_equal_data(result, expected)
