@@ -569,7 +569,10 @@ def test_over_with_nulls_in_partition(
     ],
 )
 def test_over_when_then_aggregation_partition_by(
-    constructor: Constructor, expr: nw.Expr, expected_c: list[float]
+    request: pytest.FixtureRequest,
+    constructor: Constructor,
+    expr: nw.Expr,
+    expected_c: list[float],
 ) -> None:
     # responsible for downstream failure in tubular
     # tests/imputers/test_ModeImputer.py::TestFit::test_learnt_values_tied_weighted[input_col1-weight_col1-b-False-pandas]
@@ -577,6 +580,9 @@ def test_over_when_then_aggregation_partition_by(
     # https://github.com/narwhals-dev/narwhals/issues/3300
     if "duckdb" in str(constructor) and DUCKDB_VERSION < (1, 3):
         pytest.skip()
+    if "cudf" in str(constructor):
+        request.applymarker(pytest.mark.xfail(reason="Value mismatch"))
+
     data = {"a": [1, 1, None, 3, 3], "b": [1, 3, 4, 5, 6], "g": [1, 1, 2, 3, 3]}
     df = nw.from_native(constructor(data))
     result = df.select("a", "b", c=expr).sort("b")
