@@ -7,7 +7,7 @@ import pytest
 import narwhals as nw
 from narwhals._utils import Implementation
 from narwhals.dependencies import get_cudf, get_modin, get_polars
-from tests.utils import DUCKDB_VERSION, POLARS_VERSION, Constructor, assert_equal_data
+from tests.utils import POLARS_VERSION, Constructor, assert_equal_data
 
 if TYPE_CHECKING:
     from narwhals._typing import Arrow, Dask, IntoBackend, Modin, Pandas, Polars
@@ -54,6 +54,7 @@ def test_collect_to_valid_backend_pandas(
     constructor: Constructor, backend: Pandas
 ) -> None:
     pytest.importorskip("pandas")
+    pytest.importorskip("pyarrow")
     import pandas as pd
 
     df = nw.from_native(constructor(data))
@@ -68,6 +69,7 @@ def test_collect_to_valid_backend_pandas(
 def test_collect_to_valid_backend_polars(
     constructor: Constructor, backend: Polars
 ) -> None:
+    pytest.importorskip("pyarrow")
     pytest.importorskip("polars")
     import polars as pl
 
@@ -96,6 +98,7 @@ def test_collect_to_valid_backend_pyarrow(
 )
 def test_collect_to_valid_backend_pandas_mod(constructor: Constructor) -> None:
     pytest.importorskip("pandas")
+    pytest.importorskip("pyarrow")
     import pandas as pd
 
     df = nw.from_native(constructor(data))
@@ -107,6 +110,7 @@ def test_collect_to_valid_backend_pandas_mod(constructor: Constructor) -> None:
     "ignore:is_sparse is deprecated and will be removed in a future version."
 )
 def test_collect_to_valid_backend_polars_mod(constructor: Constructor) -> None:
+    pytest.importorskip("pyarrow")
     pytest.importorskip("polars")
     import polars as pl
 
@@ -163,12 +167,7 @@ def test_collect_with_kwargs(constructor: Constructor) -> None:
     assert_equal_data(result, expected)
 
 
-def test_collect_empty(constructor: Constructor, request: pytest.FixtureRequest) -> None:
-    if any(x in str(constructor) for x in ("sqlframe", "ibis")) and DUCKDB_VERSION >= (
-        1,
-        4,
-    ):
-        request.applymarker(pytest.mark.xfail)
+def test_collect_empty(constructor: Constructor) -> None:
     df = nw.from_native(constructor({"a": [1, 2, 3]}))
     lf = df.filter(nw.col("a").is_null()).with_columns(b=nw.lit(None)).lazy()
     result = lf.collect()
