@@ -12,7 +12,8 @@ def test_get_column(constructor_eager: ConstructorEager) -> None:
     assert_equal_data({"a": result}, {"a": [1, 2]})
     assert result.name == "a"
     with pytest.raises(
-        (KeyError, TypeError), match=r"Expected str|'int' object cannot be converted|0"
+        (KeyError, TypeError),
+        match=r"Expected str|'int' object cannot be (converted|cast)|0",
     ):
         # Check that trying to get a column by position is disallowed here.
         nw.from_native(df, eager_only=True).get_column(0)  # type: ignore[arg-type]
