@@ -3,10 +3,8 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Any, Callable, cast
 
 import hypothesis.strategies as st
-import numpy as np
 import pytest
 from hypothesis import assume, given
-from hypothesis.extra.numpy import arrays
 
 import narwhals as nw
 from tests.conftest import pandas_constructor, pyarrow_table_constructor
@@ -17,6 +15,7 @@ if TYPE_CHECKING:
 
     from narwhals.typing import IntoDataFrame
 
+pytest.importorskip("pandas")
 pytest.importorskip("polars")
 import polars as pl
 
@@ -73,6 +72,10 @@ single_selector = st.one_of(
 
 @st.composite
 def tuple_selector(draw: st.DrawFn) -> tuple[Any, Any]:
+    pytest.importorskip("numpy")
+    import numpy as np
+    from hypothesis.extra.numpy import arrays
+
     rows = st.one_of(
         st.lists(
             st.integers(
