@@ -31,7 +31,7 @@ expected = {
 
 
 def test_split_list_get(request: pytest.FixtureRequest, constructor: Constructor) -> None:
-    if any(backend in str(constructor) for backend in ("dask", "cudf")):
+    if any(backend in str(constructor) for backend in ("dask",)):
         request.applymarker(pytest.mark.xfail)
 
     if "pandas" in str(constructor):
