@@ -65,6 +65,15 @@ def csv_path(
     return _into_file_source(fp, request.param)
 
 
+@pytest.fixture(scope="module", params=["str", "Path", "PathLike"])
+def csv_path_sep(
+    tmp_path_factory: pytest.TempPathFactory, request: pytest.FixtureRequest
+) -> FileSource:
+    fp = tmp_path_factory.mktemp("data") / "file.csv"
+    pl.DataFrame(data).write_csv(fp, separator="|")
+    return _into_file_source(fp, request.param)
+
+
 @pytest.fixture(scope="module", params=["str", "Path", "PathLike"])
 def parquet_path(
     tmp_path_factory: pytest.TempPathFactory, request: pytest.FixtureRequest
@@ -88,8 +97,11 @@ def native_namespace(cb: Constructor, /) -> ModuleType:
     return nw.get_native_namespace(nw.from_native(cb(data)))  # type: ignore[no-any-return]
 
 
-def test_read_csv(csv_path: FileSource, eager_backend: EagerAllowed) -> None:
+def test_read_csv(
+    csv_path: FileSource, csv_path_sep: FileSource, eager_backend: EagerAllowed
+) -> None:
     assert_equal_eager(nw.read_csv(csv_path, backend=eager_backend))
+    assert_equal_eager(nw.read_csv(csv_path_sep, backend=eager_backend, separator="|"))
 
 
 @skipif_pandas_lt_1_5
@@ -97,8 +109,14 @@ def test_read_csv_kwargs(csv_path: FileSource) -> None:
     pytest.importorskip("pandas")
     pytest.importorskip("pyarrow")
     import pandas as pd
+    from pyarrow import csv
 
     assert_equal_eager(nw.read_csv(csv_path, backend=pd, engine="pyarrow"))
+    assert_equal_eager(
+        nw.read_csv(
+            csv_path, backend="pyarrow", parse_options=csv.ParseOptions(delimiter=",")
+        )
+    )
 
 
 @lazy_core_backend
@@ -108,7 +126,9 @@ def test_read_csv_raise_with_lazy(backend: _LazyOnly) -> None:
         nw.read_csv("unused.csv", backend=backend)  # type: ignore[arg-type]
 
 
-def test_scan_csv(csv_path: FileSource, constructor: Constructor) -> None:
+def test_scan_csv(
+    csv_path: FileSource, csv_path_sep: FileSource, constructor: Constructor
+) -> None:
     kwargs: dict[str, Any]
     if "sqlframe" in str(constructor):
         kwargs = {"session": sqlframe_session(), "inferSchema": True, "header": True}
@@ -118,6 +138,7 @@ def test_scan_csv(csv_path: FileSource, constructor: Constructor) -> None:
         kwargs = {}
     backend = native_namespace(constructor)
     assert_equal_lazy(nw.scan_csv(csv_path, backend=backend, **kwargs))
+    assert_equal_lazy(nw.scan_csv(csv_path_sep, backend=backend, separator="|", **kwargs))
 
 
 @skipif_pandas_lt_1_5
@@ -185,3 +206,59 @@ def test_scan_fail_spark_like_without_session(
     pattern = re.compile(r"spark.+backend.+require.+session", re.IGNORECASE)
     with pytest.raises(ValueError, match=pattern):
         getattr(nw, scan_method)("unused.csv", backend=backend)
+
+
+@pytest.mark.parametrize("csv_path", ["str"], indirect=True)
+def test_read_csv_raise_sep_multiple_lazy(csv_path: FileSource) -> None:
+    pytest.importorskip("duckdb")
+    pytest.importorskip("pandas")
+    pytest.importorskip("pyarrow")
+    pytest.importorskip("sqlframe")
+    import duckdb
+    import pandas as pd
+    import pyarrow as pa
+    import sqlframe
+    from pyarrow import csv
+    from sqlframe.duckdb import DuckDBSession
+
+    msg = "do not match:"
+    with pytest.raises(TypeError, match=msg):
+        nw.read_csv(
+            csv_path,
+            backend=pa,
+            separator="|",
+            parse_options=csv.ParseOptions(delimiter=";"),
+        )
+    with pytest.raises(TypeError, match=msg):
+        nw.scan_csv(
+            csv_path,
+            backend=pa,
+            separator="|",
+            parse_options=csv.ParseOptions(delimiter=";"),
+        )
+    with pytest.raises(TypeError, match=msg):
+        nw.read_csv(csv_path, backend=pd, separator="|", sep=";")
+    with pytest.raises(TypeError, match=msg):
+        nw.scan_csv(csv_path, backend=pd, separator="|", sep=";")
+    with pytest.raises(TypeError, match=msg):
+        nw.scan_csv(csv_path, backend=duckdb, separator="|", delimiter=";")
+    with pytest.raises(TypeError, match=msg):
+        nw.scan_csv(csv_path, backend=duckdb, separator="|", delim=";")
+    with pytest.raises(TypeError, match=msg):
+        nw.scan_csv(
+            csv_path,
+            backend=sqlframe,
+            separator="|",
+            sep=";",
+            session=DuckDBSession(),
+            inferSchema=True,
+        )
+    with pytest.raises(TypeError, match=msg):
+        nw.scan_csv(
+            csv_path,
+            backend=sqlframe,
+            separator="|",
+            delimiter=";",
+            session=DuckDBSession(),
+            inferSchema=True,
+        )
