@@ -22,3 +22,9 @@ def test_item(constructor_eager: ConstructorEager, index: int, expected: int) ->
         match=re.escape("can only call '.item()' if the Series is of length 1,"),
     ):
         series.item(None)
+
+
+def test_out_of_range(constructor_eager: ConstructorEager) -> None:
+    series = nw.from_native(constructor_eager({"a": [1, 2]}), eager_only=True)["a"]
+    with pytest.raises(IndexError, match="out of range"):
+        series.item(2)
