@@ -31,9 +31,15 @@ def series_from_native(native: IntoSeriesT) -> nw.Series[IntoSeriesT]:
 
 
 def test_self_equal(
-    constructor_eager: ConstructorEager, testing_data: Data, testing_schema: IntoSchema
+    request: pytest.FixtureRequest,
+    constructor_eager: ConstructorEager,
+    testing_data: Data,
+    testing_schema: IntoSchema,
 ) -> None:
     """Test that a series is equal to itself, including nested dtypes with nulls."""
+    if "cudf" in str(constructor_eager):
+        # TODO(FBruzzesi): Investigate which conversion is failing aside from nested dtypes
+        request.applymarker(pytest.mark.xfail)
     if "pandas" in str(constructor_eager):
         if PANDAS_VERSION < (2, 2):  # pragma: no cover
             reason = "Pandas too old for nested dtypes"
@@ -52,10 +58,13 @@ def test_self_equal(
 
     if "pyarrow_table" in str(constructor_eager):
         # Replace Enum with Categorical, since Pyarrow does not support Enum
+        data = dict(testing_data)
         schema = {**testing_schema, "enum": nw.Categorical()}
     else:
-        schema = dict(testing_schema)  # make a copy
-    df = nw.from_native(constructor_eager(testing_data), eager_only=True)
+        data = dict(testing_data)
+        schema = dict(testing_schema)
+
+    df = nw.from_native(constructor_eager(data), eager_only=True)
     for name, dtype in schema.items():
         assert_series_equal(df[name].cast(dtype), df[name].cast(dtype))
 
@@ -132,6 +141,7 @@ def test_metadata_checks_with_flags(
     ],
 )
 def test_check_order(
+    request: pytest.FixtureRequest,
     constructor_eager: ConstructorEager,
     dtype: nw.dtypes.DType,
     *,
@@ -139,6 +149,10 @@ def test_check_order(
     context: AbstractContextManager[Any],
 ) -> None:
     """Test check_order behavior with nested and simple data."""
+    if "cudf" in str(constructor_eager) and dtype.is_nested():
+        reason = "NotImplementedError"
+        request.applymarker(pytest.mark.xfail(reason=reason))
+
     if "pandas" in str(constructor_eager):
         if PANDAS_VERSION < (2, 2) and dtype.is_nested():  # pragma: no cover
             reason = "Pandas too old for nested dtypes"
@@ -244,6 +258,7 @@ def test_numeric(
     ],
 )
 def test_list_like(
+    request: pytest.FixtureRequest,
     constructor_eager: ConstructorEager,
     l_vals: list[list[Any]],
     r_vals: list[list[Any]],
@@ -252,6 +267,10 @@ def test_list_like(
     context: AbstractContextManager[Any],
     dtype: nw.dtypes.DType,
 ) -> None:
+    if "cudf" in str(constructor_eager):
+        reason = "NotImplementedError"
+        request.applymarker(pytest.mark.xfail(reason=reason))
+
     if "pandas" in str(constructor_eager):
         if PANDAS_VERSION < (2, 2):  # pragma: no cover
             reason = "Pandas too old for nested dtypes"
@@ -300,6 +319,7 @@ def test_list_like(
     ],
 )
 def test_struct(
+    request: pytest.FixtureRequest,
     constructor_eager: ConstructorEager,
     l_vals: list[dict[str, Any]],
     r_vals: list[dict[str, Any]],
@@ -307,6 +327,10 @@ def test_struct(
     check_exact: bool,
     context: AbstractContextManager[Any],
 ) -> None:
+    if "cudf" in str(constructor_eager):
+        reason = "NotImplementedError"
+        request.applymarker(pytest.mark.xfail(reason=reason))
+
     if "pandas" in str(constructor_eager):
         if PANDAS_VERSION < (2, 2):  # pragma: no cover
             reason = "Pandas too old for nested dtypes"
