@@ -8,6 +8,8 @@ from datetime import date, datetime
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Callable, cast
 
+import pytest
+
 import narwhals as nw
 from narwhals._utils import Implementation, parse_version, zip_strict
 from narwhals.dependencies import get_pandas
@@ -17,7 +19,6 @@ if TYPE_CHECKING:
     from collections.abc import Mapping, Sequence
 
     import pandas as pd
-    import pytest
     from pyspark.sql import SparkSession
     from sqlframe.duckdb import DuckDBSession
     from typing_extensions import TypeAlias
@@ -252,3 +253,15 @@ def time_unit_compat(time_unit: TimeUnit, request: pytest.FixtureRequest, /) ->
     if PANDAS_VERSION < (2,) and any(name in request_id for name in pandas_like):
         return "ns"
     return time_unit
+
+
+def is_pyspark_connect(constructor: Constructor) -> bool:
+    is_spark_connect = bool(os.environ.get("SPARK_CONNECT", None))
+    return is_spark_connect and ("pyspark" in str(constructor))
+
+
+def xfail_if_pyspark_connect(  # pragma: no cover
+    constructor: Constructor, request: pytest.FixtureRequest, reason: str = ""
+) -> None:
+    if is_pyspark_connect(constructor):
+        request.applymarker(pytest.mark.xfail(reason=reason))
