@@ -958,6 +958,17 @@ def test_deprecated_expr_methods() -> None:
     assert_equal_data(result, expected)
 
 
+def test_first_last() -> None:
+    pytest.importorskip("pandas")
+    import pandas as pd
+
+    data = {"a": [0, 0, 2, -1]}
+    df = nw_v1.from_native(pd.DataFrame(data), eager_only=True)
+    result = df.select(b=nw_v1.col("a").first(), c=nw_v1.col("a").last())
+    expected = {"b": [0], "c": [-1]}
+    assert_equal_data(result, expected)
+
+
 def test_dask_order_dependent_ops() -> None:
     # Preserve these for narwhals.stable.v1, even though they
     # raise after stable.v1.
