@@ -533,3 +533,14 @@ def test_any_value_series(constructor_eager: ConstructorEager) -> None:
 
     with pytest.warns(NarwhalsUnstableWarning):
         df["a"].any_value()
+
+
+def test_first_last() -> None:
+    pytest.importorskip("pandas")
+    import pandas as pd
+
+    data = {"a": [0, 0, 2, -1]}
+    df = nw_v2.from_native(pd.DataFrame(data), eager_only=True)
+    result = df.select(b=nw_v2.col("a").first(), c=nw_v2.col("a").last())
+    expected = {"b": [0], "c": [-1]}
+    assert_equal_data(result, expected)
